# -*- coding: utf-8 -*-
"""
ldap0.controls.openldap - classes for OpenLDAP-specific controls
"""

from __future__ import absolute_import

from ..__about__ import __version__, __author__, __license__
from . import ValueLessRequestControl, ResponseControl, KNOWN_RESPONSE_CONTROLS

import _libldap0

from pyasn1.type import univ
from pyasn1.codec.ber import decoder

__all__ = [
    'SearchNoOpControl',
]


class SearchNoOpControl(ValueLessRequestControl, ResponseControl):
    """
    No-op control attached to search operations implementing sort of a
    count operation

    see https://www.openldap.org/its/index.cgi?findid=6598#followup4
    """
    controlType = '1.3.6.1.4.1.4203.666.5.18'

    class SearchNoOpControlValue(univ.Sequence):
        pass

    def decodeControlValue(self, encodedControlValue):
        decodedValue, _ = decoder.decode(
            encodedControlValue,
            asn1Spec=self.SearchNoOpControlValue(),
        )
        self.resultCode = int(decodedValue[0])
        self.numSearchResults = int(decodedValue[1])
        self.numSearchContinuations = int(decodedValue[2])

KNOWN_RESPONSE_CONTROLS.reg(SearchNoOpControl)
